/******************************************************************************
 *                                                                            *
 * File:   noapipa.c          Version  1.00            Date: 2001-09-27       *
 *                                                                            *
 * Copyright (C) 2001 by Kostis Netzwerkberatung                              *
 * Talstr. 25, D-63322 Roedermark, Tel. +49 6074 881056, FAX 881058           *
 * kosta@kostis.de (Kosta Kostis), http://www.kostis.de/                      *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *        - disable apipa on remote registry                                  *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * History:                                                                   *
 *     2001-09-27: KK V1.00                                                   *
 *        - initial encoding                                                  *
 *                                                                            *
 *****************************************************************************/

/******************************************************************************

	this program will not run under Win9x

 *****************************************************************************/

#define _WIN32_WINNT	 0x0400

#include <windows.h>
#include <winbase.h>
#include <winreg.h>
#include <stdio.h>

#include "noapipa.h"

/******************************************************************************

	Function:
		display copyright, author and program information

	Parameters:
		FILE		*fout		output file

	Returns:
		nothing

 *****************************************************************************/

static  void    Hello
(
	FILE	*fout
)
{
	fprintf (fout, MSG_COPYRIGHT) ;
	fprintf (fout, MSG_VERSION, PRGNAM, VERSION) ;
	fprintf (fout, "\n") ;
}

/******************************************************************************

	main program

 *****************************************************************************/

int     main
(
	int	argc,
	char	*argv	[]
)
{
	LONG	rc ;
	HKEY	RegRemote ;
	DWORD	value		= REG_VAL_DISABLE ;

	/**********************************************************************

		check syntax

	 *********************************************************************/

	if (argc != 2)
	{
		Hello (stderr) ;
		fprintf (stderr, ERR_MSG_SYNTAX, PRGNAM) ;
		return (ERR_SYNTAX) ;
	}

	/**********************************************************************

		connect to remote registry

	 *********************************************************************/

	rc = RegConnectRegistry (argv [1], HKEY_LOCAL_MACHINE, &RegRemote) ;
	if (rc != ERROR_SUCCESS)
	{
		fprintf (stderr, ERR_MSG_CONNECT, PRGNAM, argv [1], rc) ;
		return (ERR_CONNECT) ;
	}

	/**********************************************************************

		open key

	 *********************************************************************/

	rc = RegOpenKeyEx
	(
		RegRemote,
		REG_KEY_TCPIP,
		0,
		KEY_WRITE,
		&RegRemote
	) ;
	if (rc != ERROR_SUCCESS)
	{
		RegCloseKey (RegRemote) ;
		fprintf (stderr, ERR_MSG_OPEN, PRGNAM, argv [1], rc) ;
		return (ERR_OPEN) ;
	}

	/**********************************************************************

		set key value

	 *********************************************************************/

	rc = RegSetValueEx
	(
		RegRemote,
		REG_VAL_APIPA,
		0,
		REG_DWORD,
		(BYTE *) &value,
		sizeof (value)
	) ;
	if (rc != ERROR_SUCCESS)
	{
		RegCloseKey (RegRemote) ;
		fprintf (stderr, ERR_MSG_SETVALUE, PRGNAM, argv [1], rc) ;
		return (ERR_SETVALUE) ;
	}

	/**********************************************************************

		close remote registry

	 *********************************************************************/

	rc = RegCloseKey (RegRemote) ;
	if (rc != ERROR_SUCCESS)
	{
		fprintf (stderr, ERR_MSG_CLOSE, PRGNAM, argv [1], rc) ;
		return (ERR_CLOSE) ;
	}

	fprintf (stderr, MSG_LOG, PRGNAM, argv [1]) ;

	return (ERR_NONE) ;
}
